# Managing Diagram Versions, Importing, and Exporting
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting#overview)
  * [Version History of Diagrams](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting#version-history-of-diagrams)
  * [Accessing Previous Versions](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting#accessing-previous-versions)
  * [Restoring a Previous Version or Saving it as New](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting#restoring-a-previous-version-or-saving-it-as-new)
  * [Adding or Editing Version Information](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting#adding-or-editing-version-information)
  * [Comparing Diagram Versions](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting#comparing-diagram-versions)
  * [Importing Diagrams from a Device](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting#importing-diagrams-from-a-device)
  * [Importing Diagrams from Another Diagram](https://help.sap.com/docs/leanix/ea/diagram-versions-importing-and-exporting#importing-diagrams-from-another-diagram)


View all
Diagram versioning, import, and export features enable users to track changes, restore or compare diagram versions, and seamlessly transfer diagrams between tools such as draw.io, Lucidchart, and Visio. These capabilities support collaboration, version control, and interoperability across diagramming platforms.
